@@ -273,30 +273,13 @@ class DataProcessor(object):
         """
         if cols:
             if self.conf.process.date_cols_num_cores == 1 or self.conf.process.date_cols_num_cores is None:
-                data = self._handle_date_cols(data, cols)
+                data = handle_date_cols(data, cols)
             else:
-                data = parrallelize_dataframe(data, partial(self._handle_date_cols, cols=cols),
+                data = parrallelize_dataframe(data, partial(handle_date_cols, cols=cols),
                                               num_cores=self.conf.process.date_cols_num_cores)
 
             return data
 
-    def _handle_date_cols(self, data, cols=None):
-        """Process the date columns. First, convert each column to datetime object and then extract the requested items
-        from them to create the new columns.
-
-        :param data: pandas dataframe
-        :param cols: the date columns to be processed
-        :return: the updated dataframe with the new columns
-        """
-        for col, date_items in cols.items():
-            data[col] = pd.to_datetime(data[col],
-                                       errors='coerce',
-                                       infer_datetime_format=True)
-            for item in date_items:
-                data.loc[:, f"{col}_{item}"] = getattr(data[col].dt, item)
-
-        return data
-
     def handle_mean(self, data):
         """Accept a dataframe and compute the mean of all columns in that dataframe and save them in a dictionary (mean_dict)
         in which the key is the column name and the value is the average value of that column.
@@ -781,7 +764,9 @@ class LearnerLabelEncoder:
                             warnings.warn(f"Label {new_class} in column {col} is not in training. Encoding this new "
                                           f"labels with {max_label + 1}...", Warning)
                             self._labels_dict[col][new_class] = max_label + 1
-                data[col] = data[col].apply(lambda x: self._labels_dict[col][x])
+
+                data[col] = data[col].apply(self._labels_dict[col].get)
+                # data[col] = data[col].apply(lambda x: self._labels_dict[col][x])
 
     def fit_transform(self, data, cols):
         """Fit and transform columns using Learner LabelEncoder.
@@ -1084,3 +1069,25 @@ def delete_keys_from_dict(dictionary, keys):
 
     for key in keys:
         dictionary.pop(key)
+
+
+def handle_date_cols(data, cols=None):
+    """The function was moved out of the DataProcessor class because we'll have issue with using custom scoring
+    functions and get can't pickle <function> when doing multiprocessing.
+    Process the date columns. First, convert each column to datetime object and then extract the requested items
+    from them to create the new columns.
+
+    :param data: pandas dataframe
+    :param cols: the date columns to be processed
+    :return: the updated dataframe with the new columns
+    """
+    for col, date_items in cols.items():
+        data[col] = pd.to_datetime(data[col],
+                                   errors='coerce',
+                                   infer_datetime_format=True)
+        for item in date_items:
+            data.loc[:, f"{col}_{item}"] = getattr(data[col].dt, item)
+
+    return data
+
+
